@@ -19,15 +19,15 @@ oxySol <-
   Cstar1 <- exp(lnCstar)
   if (is.null(P)) {
   ## Equilibrium DO Cstar at P = 1 atm
-      return(Cstar1)
+      Cstar1
   } else {   
   ## Transform for nonstandard pressure
     Pwv = (1 - 0.000537 * S) * exp(18.1973 * (1 - 373.16/T) +
       3.1813e-07 * (1 - exp(26.1205 * (1 - T/373.16))) - 0.018726 *
       (1 - exp(8.03945 * (1 - 373.16/T))) + 5.02802 * log(373.16/T))
     theta = 0.000975 - 1.426e-05 * t + 6.436e-08 * t^2
-    return(Cstar1 * P * (1 - Pwv/P) * (1 - theta * P)/((1 - Pwv) * (1
-      - theta)))
+    Cstar1 * P * (1 - Pwv/P) * (1 - theta * P)/((1 - Pwv) * (1
+      - theta))
   }
 
 }
