@@ -20,7 +20,7 @@ setMethod(
     d1 <- data.frame(yr = floor(time(x)), mon = cycle(x), val =
     	as.numeric(x))
     mons <- mon.range[1]:mon.range[2]
-    d2 <- subset(d1, mon %in% mons)
+    d2 <- d1[d1$mon %in% mons, ]
     yrs <- unique(d2$yr)
     yrs.ok <- table(d2$yr, is.na(d2$val))[, 1] == length(mons)
 
@@ -87,7 +87,7 @@ setMethod(
     	as.Date("1970-01-01")), yr = years(indexx), mon =
     	monthNum(indexx), val = as.numeric(x))
     mons <- mon.range[1]:mon.range[2]
-    d2 <- subset(d1, mon %in% mons)
+    d2 <- d1[d1$mon %in% mons, ]
     yrs <- unique(d2$yr)
     n <- table(d2$yr, is.na(d2$val))[, 1]
 
